@@ -1,8 +1,9 @@
 <?php
 
 global $username, $key, $imapServerAddress, $imapPort, 
-       $imap_stream, $imapConnection, 
-       $UseSeparateImapConnection;
+       $imap_stream, $imapConnection, $UseSeparateImapConnection,
+       $cq_check_quota_debug, $cq_use_1000KB_per_MB,
+       $cq_total, $cq_maxcount;
 
 /*
  * Detect if we have already connected to IMAP or not.
@@ -26,7 +27,7 @@ else
 }
 
 $cq_usage = sqimap_get_quota($stream, 'INBOX');
-if ($quota_usage_debug)
+if ($cq_check_quota_debug)
 {
 	echo "Usage is: <br>";
 	sm_print_r($cq_usage);
@@ -123,9 +124,9 @@ if ( strpos($cq_usage[0], 'NOQUOTA') === FALSE)
 			$cq_t_unit = "KB";
 	}
 
-	if ( $fn_left == 1 )
+	if ( isset($fn_left) && $fn_left == 1 )
 		include("show_graph.php");
-	if ( $fn_motd == 1 )
+	if ( isset($fn_motd) && $fn_motd == 1 )
 		include("show_motd.php");
 
 	$cq_size_quota = FALSE;
@@ -157,7 +158,7 @@ if ( !$previously_connected )
 */
 function sqimap_get_quota ($imap_stream, $mailbox) 
 {
-	global $quota_usage_debug;
+	global $cq_check_quota_debug;
 
 	if (check_quota_capability($imap_stream)) 
 	{
@@ -169,7 +170,7 @@ function sqimap_get_quota ($imap_stream, $mailbox)
 		if (check_sm_version(1, 5, 0))
 			$read_ary = $read_ary['a001'];
 
-		if ($quota_usage_debug) 
+		if ($cq_check_quota_debug) 
 		{
 			echo "IMAP command sent: $imap_command<br />";
 			echo 'IMAP response recieved:';
