@@ -2,7 +2,8 @@
 
 function check_quota_left_do() {
 
-	include("config.php");
+global $cq_check_quota_type;
+
 	if ( $cq_check_quota_type == 0 )
 	{
 		$fn_left = 1;
@@ -17,7 +18,8 @@ function check_quota_left_do() {
 
 function check_quota_MOTD_do() {
 
-	include("config.php");
+global $cq_check_quota_type;
+
 	if ( $cq_check_quota_type == 0 )
 	{
 		$fn_motd = 1;
