@@ -16,9 +16,9 @@ function squirrelmail_plugin_init_check_quota() {
 }
 
 function check_quota_version() {
-    return '1.3';
+    return '1.4';
 }
 
-include_once("functions.php");
+include_once(SM_PATH . "plugins/check_quota/functions.php");
 
 ?>
